@@ -7,8 +7,8 @@ from .analysis import *
 from . import core
 from .core import *
 
-from . import simulation
-from .simulation import *
+# from . import simulation
+# from .simulation import *
 
 # from . import external
 # from .external import *
@@ -29,7 +29,7 @@ __all__ = [
     'io',
     'include_dir',
     'misc',
-    'simulation',
+    # 'simulation',
     '__version__'
 ]
 
